@@ -22,7 +22,8 @@ from sklearn.impute import IterativeImputer  # Used in : Data_Engineering
 from sklearn.linear_model import BayesianRidge  # Used in : Data_Engineering
 from sklearn.exceptions import DataConversionWarning
 logger = logging.getLogger(__name__)
-__all__ = ['preprocessing_training']
+__all__ = ['preprocessing_training','preprocessing_preleads']
+
 
 
 def preprocessing_training_common(df, config, industry_dictionary, state_dictionary,
@@ -165,3 +166,67 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     return df_leads_clean,imp
 
 
+def preprocessing_preleads(df,industry_dictionary,mx_bv_dictionary,mx_prob_dictionary,state_dictionary,imputer,sample):
+    """Pre processing function for batch preleads scoring
+    
+    Args:
+        df ([type]): [description]
+    """
+    df=utils.reduce_mem_usage(df)
+    # make a copy of the dataset
+    df_preleads_clean = df.copy()
+    # Set Types
+    df_preleads_clean= devutils.set_dataframe_columntypes(df_leads_clean)
+
+    # Map industry dictionary
+    df_preleads_clean['Industry']= df_preleads_clean['Industry'].map(industry_dictionary)
+    # map mxtypes
+    df_preleads_clean= devutils.clean_mxtype_using_dictionary(df=df_preleads_clean, mx_bv_dict=mx_bv_dictionary,mx_prob_dict=mx_prob_dictionary)
+    # map states dictionary
+    df_preleads_clean['State']= df_preleads_clean['State'].map(state_dictionary)
+
+    #Fill NA with Uknown" in the following columns:
+    cols_to_fill=['Type','Department','State']
+    df_preleads_clean= devutils.fill_na_with_unknown(df=df_preleads_clean, columns= cols_to_fill)
+
+    # Create company years column
+    df_preleads_clean= devutils.create_company_years_column(df=df_preleads_clean)
+
+    # Create new seniorities and the rest go to "other"
+    df_preleads_clean= devutils.fill_seniority_column(df=df_preleads_clean)
+
+    # Fix errors in company followers
+    df_preleads_clean= devutils.clean_companyfollowers_text(df=df_preleads_clean)
+
+    # Converting kw_key and technologies list of words to an int, using regex
+    df_preleads_clean=devutils.convert_kwkey_specialties_and_technologies_to_int(df=df_preleads_clean)
+
+    # Historic variables, fill nulls with 0.
+    df_preleads_clean=devutils.fill_historic_variables(df=df_preleads_clean)
+
+    #Impute Lead followers NA using regression
+    impute_columns = ['LeadFollowers','CompanyFollowers','QEmployeesOnLinkedIn','LeadConnections']
+    df_preleads_clean=devutils.impute_nas(df=df_preleads_clean,columns_to_impute=impute_columns,imp=imputer)
+
+    # Log transformation
+    cols_to_transform= ["QEmployeesOnLinkedIn","CompanyFollowers","LeadFollowers"]
+    df_preleads_clean=devutils.log_transformation(df_preleads_clean,columns=cols_to_transform)
+
+    days_list = [60,90,120]
+    for day in days_list:
+        df_preleads_clean= devutils.create_new_position_flag(df=df_preleads_clean,days=day)
+
+    # Dropping unused variables ( In this Case: delete also target columns)
+    cols_to_drop = ["PreviousStatus","MXType", "DaysSincePositionStart", "Size",'kw_key','Title','LeadConnections','Specialties','Technologies','BV','IDEmailStatus','Ranking',"Rating",'MonthStatus']
+    df_preleads_clean = utils.drop_columns(df=df_preleads_clean,columns=cols_to_drop)            
+
+    nna = df_preleads_clean.isna().sum()
+    logging.info( f"NA in final dataframe:" )
+    logging.info( f"{nna}" )
+
+    df_preleads_clean = reduce_mem_usage_category(df_preleads_clean)
+    df_preleads_clean = utils.one_hot_encoding(df=df_preleads_clean)
+
+    _, df_preleads_clean = sample.align(df_preleads_clean,join='left',axis=1,fill_value=np.nan)
+    
+    return df_preleads_clean
